
/*

	BuzzClock

	 1997 Steve Klingsporn
	moofie@pdicamillo.ne.highway1.com (temporary)

	    File:  TClockView.h

	Contains:  Clock view class definition

	   Notes:  Version 1.1

*/

#pragma once

#ifndef _TCLOCKVIEW_H
#define _TCLOCKVIEW_H

#ifndef _VIEW_H
#include <View.h>
#endif

#ifndef _BITMAP_H
#include <Bitmap.h>
#endif

#ifndef _VOLUME_H
#include <Volume.h>
#endif

#ifndef _DIRECTORY_H
#include <Directory.h>
#endif

#ifndef _FILE_H
#include <File.h>
#endif

#ifndef __time_h__
#include <time.h>
#endif

#ifndef __string__
#include <string.h>
#endif


/**
	Messages
	
	The view handles three messages currently: One which toggles
	the display of seconds, one which toggles the display
	of time in 24-hour mode, and one which toggles beeping on the
	hour.
**/

enum
{
	MSG_TOGGLE_SECONDS	 =	'secs',
	MSG_TOGGLE_24_TIME	 =	'24hr',
	MSG_TOGGLE_BEEP		 =	'beep',
	MSG_COPY_TIME_STAMP  =	'copy'
};


/**
	Constants
	
	Various pre-defined colors for drawing in the view
	and other neat stuff.
**/

const rgb_color kTitleBarBackgroundColor		= {255, 203, 0};
const rgb_color kTitleBarShadowColor			= {203, 152, 51};
const rgb_color kTitleBarHiliteColor			= {255, 255, 102};
const rgb_color	kPanelBackgroundColor			= {208, 208, 208};
const rgb_color kPanelShadowColor				= {136, 136, 136};
const rgb_color kPanelHiliteColor				= {250, 250, 250};
const rgb_color	kTextColor		 				= {0, 0, 0};

const BRect 	kCloseBoxFrame 		  			= BRect(3,3,11,11);
const float		kCloseBoxSize					= 8.0;
const int		kDateModeDelaySeconds 			= 3;

const float		kTitleBarLeftMargin				= 14.0;
const float		kPanelLeftMargin				= kTitleBarLeftMargin + 1.0;
const BPoint	kTextPoint						= BPoint(24, 11);
const float		kMainMenuOffset					= 182.0;

/**
	Close Box Bitmaps
	
	Bitmap character array data for the two close box states.
**/

static unsigned char kCloseBoxBitmapData[] = 
{
	0x5d,0x5d,0x5d,0x5d,0x5d,0x5d,0x5d,0x5d,0xf9,0x3f,0x3f,0x3f,0x5d,0xfc,0xfc,
	0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0x3f,0x3f,0x3f,0x5d,0xfc,0xfc,0xe5,0xe5,0xf9,
	0xf9,0x5d,0xfc,0x3f,0x3f,0x3f,0x5d,0xfc,0xe5,0xe5,0xf9,0xe5,0xf9,0x5d,0xfc,
	0x3f,0x3f,0x3f,0x5d,0xfc,0xe5,0xf9,0xe5,0xf9,0xf9,0x5d,0xfc,0x3f,0x3f,0x3f,
	0x5d,0xfc,0xf9,0xe5,0xf9,0xf9,0xbd,0x5d,0xfc,0x3f,0x3f,0x3f,0x5d,0xfc,0xf9,
	0xf9,0xbd,0xbd,0xbd,0x5d,0xfc,0x3f,0x3f,0x3f,0x5d,0xfc,0x5d,0x5d,0x5d,0x5d,
	0x5d,0x5d,0xfc,0x3f,0x3f,0x3f,0xf9,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,
	0x3f,0x3f,0x3f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
};


static unsigned char kHilitedCloseBoxBitmapData[] = 
{
	0x98,0x98,0x98,0x98,0x98,0x98,0x98,0x98,0x98,0x3f,0x3f,0x3f,0x98,0x98,0x98,
	0x98,0x98,0x98,0x98,0x98,0xfc,0x3f,0x3f,0x3f,0x98,0x98,0xbd,0xbd,0xbd,0xf9,
	0xf9,0xfc,0xfc,0x3f,0x3f,0x3f,0x98,0x98,0xbd,0xf9,0xf9,0xf9,0xe5,0xfc,0xfc,
	0x3f,0x3f,0x3f,0x98,0x98,0xbd,0xf9,0xf9,0xe5,0xe5,0xfc,0xfc,0x3f,0x3f,0x3f,
	0x98,0x98,0xf9,0xf9,0xe5,0xe5,0xe5,0xfc,0xfc,0x3f,0x3f,0x3f,0x98,0x98,0xf9,
	0xe5,0xe5,0xe5,0xe5,0xfc,0xfc,0x3f,0x3f,0x3f,0x98,0x98,0xfc,0xfc,0xfc,0xfc,
	0xfc,0xfc,0xfc,0x3f,0x3f,0x3f,0x98,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,
	0x3f,0x3f,0x3f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
};


class TClockWindow;

class TClockView : public BView
{
	public:
	
						TClockView(BRect frame);
						~TClockView();
						
		void			MouseDown(BPoint where);
		void			MessageReceived(BMessage *message);
		void			Pulse();
		void			Draw(BRect updateRegion);
		void			AttachedToWindow();
		void			AdjustMenuItems();
		
	private:	
	
		char			_lastTimeString[12];
		bool			_closeBoxState;
		
		bool			_showSeconds;
		bool			_militaryTime;
		bool			_beepOnHour;
		bool			_dateMode;
		int				_dateModeDelay;
		
		BPopUpMenu		*_mainMenu;
		BBitmap			*_closeBoxBitmaps[2];
		BBitmap			*_clockBitmap;
		BView			*_clockView;	

		void			CreateMainMenu();
		void			UpdateClockBitmap();
		bool			TimeString(char *timeString);
		void			DateString(char *dateString);
		void			CopyAsTimeStamp();
		
		BFile			*GetSettingsFile();
		void			ReadSettings();
		void			WriteSettings();
};

#endif