
/*

	BuzzClock

	 1997 Steve Klingsporn
	moofie@pdicamillo.ne.highway1.com (temporary)

	    File:  TClockWindow.cpp

	Contains:  Implementation of clock window class

	   Notes:  Version 1.1

*/

#ifndef _TCLOCKWINDOW_H
#include "TClockWindow.h"
#endif

#ifndef _TCLOCKVIEW_H
#include "TClockView.h"
#endif


/**
	TClockWindow()
	
	Constructor.  Turns off discipline for faster window drawing, creates
	the clock view, and sets the pulse rate so we receive pulse messages
	approximately every second.
**/

TClockWindow::TClockWindow(BRect frame)
			 :BWindow(frame, "BuzzClock", B_BORDERED_WINDOW, 
					  B_WILL_ACCEPT_FIRST_CLICK | B_WILL_FLOAT | B_PULSE_NEEDED, B_ALL_WORKSPACES)
{
	SetDiscipline(false);
	_clockView = new TClockView(Bounds());
	AddChild(_clockView);
	SetPulseRate(kClockWindowPulseRate);
	RemoveShortcut('W', B_COMMAND_KEY);
}


/**
	MoveWindowToCorner()
	
	Moves the window to the upper right-hand corner of the screen
**/

void TClockWindow::MoveWindowToCorner()
{
	screen_info		screenInfo;
	
	get_screen_info(&screenInfo);
	MoveTo(screenInfo.frame.Width() - kClockWindowFrame.Width(), 0);
}


/**
	ScreenChanged()
	
	Called by the system whenever the bounds or color depth of the
	screen changes.  Also called when the current workspace changes.
	Our window appears in every workspace.  This moves the window
	into the upper right-hand corner of the new screen coordinates.
**/

void TClockWindow::ScreenChanged(BRect screenSize, color_space depth)
{
#pragma unused(screenSize, depth)

	MoveWindowToCorner();
}
